@@ -18,12 +18,13 @@ extern SEXP crtnorm(SEXP, SEXP, SEXP, SEXP);
 extern SEXP crtgamma(SEXP, SEXP, SEXP, SEXP);
 extern SEXP cdraw_lambda_i(SEXP, SEXP, SEXP, SEXP);
 /*extern SEXP cdpmbart(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP cdpmwbart(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);*/
+extern SEXP cdpmwbart(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP cdpgbart(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);*/
 
 static const R_CallMethodDef CallEntries[] = {
     {"cpbart",  (DL_FUNC) &cpbart,  27},
     {"clbart",  (DL_FUNC) &clbart,  24},
-/*    {"cmbart",  (DL_FUNC) &cmbart,  29},*/
+/*  {"cmbart",  (DL_FUNC) &cmbart,  29},*/
     {"cpwbart", (DL_FUNC) &cpwbart,  3},
     {"cwbart",  (DL_FUNC) &cwbart,  31},
     {"cgbart",  (DL_FUNC) &cgbart,  30},
@@ -34,7 +35,8 @@ static const R_CallMethodDef CallEntries[] = {
     {"crtnorm", (DL_FUNC) &crtnorm,  4},
     {"crtgamma",(DL_FUNC) &crtgamma, 4},
     {"cdraw_lambda_i", (DL_FUNC) &cdraw_lambda_i, 4},
-/*  {"cdpmbart",(DL_FUNC) &cdpmbart,25},
+/*  {"cdpgbart",(DL_FUNC) &cdpgbart,35},
+    {"cdpmbart",(DL_FUNC) &cdpmbart,25},
     {"cdpmwbart",(DL_FUNC) &cdpmwbart,27}, */
     {NULL, NULL, 0}
 };
